SimpleLocalizations class abstract

Class to implement localizations in your packages and applications simply.

Constructors

SimpleLocalizations(Locale currentLocale)
Default constructor

Properties

currentLocale ↔ Locale
Current location loaded
getter/setter pair
customValues → Map<String, Map<dynamic, String>>?
Custom values, used to modify certain values, this property should only be used in custom package locations that use internationalization.
no setter
defaultLocale → Locale
If your device location is not supported, this will be the default location to use
no setter
hashCode → int
The hash code for this object.
no setterinherited
localizedValues → Map<String, Map<dynamic, String>>
Message values to be used by your app for all supported locations.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suportedLocales → Iterable<Locale>
Locations supported by your app
no setter

Methods

getLocalizedValue(dynamic localizedName) → String
Function to get message to use
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](dynamic message) → String
Operator to get message to use

Static Methods

of<T>(BuildContext context, T orDefault(Locale locale)) → T
Get current location instance